@@ -9,6 +9,7 @@ from threading import Lock
 
 from argostranslate import settings
 from argostranslate import utils
+from argostranslate import networking
 from argostranslate.utils import info, error
 
 """
@@ -39,20 +40,27 @@ class IPackage:
 
     Attributes:
         package_path (Path): The path to the installed package. None if not installed.
+
         package_version (str): The version of the package.
+        
         argos_version (str): The version of Argos Translate the package is intended for.
+
         from_code (str): The code of the language the package translates from.
+
         from_name (str): Human readable name of the language the package translates from.
+
         to_code (str): The code of the language the package translates to.
+
         to_name (str): Human readable name of the language the package translates to.
+
         links [list(str)]: A list of links to download the package
 
+
     Packages are a zip archive of a directory with metadata.json
     in its root the .argosmodel file extension. By default a
-    OpenNMT CTranslate2 directory named model/ created using
-    ct2-opennmt-tf-converter is expected in the root directory
+    OpenNMT CTranslate2 directory named model/ is expected in the root directory
     along with a sentencepiece model named sentencepiece.model
-    for tokenizing and Stanza for sentence boundary detection.
+    for tokenizing and Stanza data for sentence boundary detection.
     Packages may also optionally have a README.md in the root.
 
     from_code and to_code should be ISO 639 codes if applicable.
@@ -163,8 +171,22 @@ class Package(IPackage):
         return self.get_readme()
 
 
+def install_from_path(path):
+    """Install a package file (zip archive ending in .argosmodel).
+
+    Args:
+        path (pathlib): The path to the .argosmodel file to install.
+
+    """
+    with package_lock:
+        if not zipfile.is_zipfile(path):
+            raise Exception("Not a valid Argos Model (must be a zip archive)")
+        with zipfile.ZipFile(path, "r") as zip:
+            zip.extractall(path=settings.package_data_dir)
+
+
 class AvailablePackage(IPackage):
-    """A package available for download"""
+    """A package available for download and installation"""
 
     def __init__(self, metadata):
         """Creates a new AvailablePackage from a metadata object"""
@@ -172,7 +194,6 @@ class AvailablePackage(IPackage):
 
     def download(self):
         """Downloads the AvailablePackage and returns its path"""
-        url = self.links[0]
         filename = argospm_package_name(self) + ".argosmodel"
 
         # Install sbd package if needed
@@ -190,34 +211,22 @@ class AvailablePackage(IPackage):
                     install_from_path(download_path)
 
         filepath = settings.downloads_dir / filename
-        try:
-            response = urllib.request.urlopen(url)
-        except Exception as err:
-            error(err)
-            return
-        data = response.read()
-        with open(filepath, "wb") as f:
-            f.write(data)
+        if not filepath.exists():
+            data = networking.get_from(self.links)
+            if data is None:
+                raise Exception(f"Download failed for {url}")
+            with open(filepath, "wb") as f:
+                f.write(data)
         return filepath
 
+    def install(self):
+        download_path = self.download()
+        install_from_path(download_path)
+
     def get_description(self):
         return "{} → {}".format(self.from_name, self.to_name)
 
 
-def install_from_path(path):
-    """Install a package file (zip archive ending in .argosmodel).
-
-    Args:
-        path (pathlib): The path to the .argosmodel file to install.
-
-    """
-    with package_lock:
-        if not zipfile.is_zipfile(path):
-            raise Exception("Not a valid Argos Model (must be a zip archive)")
-        with zipfile.ZipFile(path, "r") as zip:
-            zip.extractall(path=settings.package_data_dir)
-
-
 def uninstall(pkg):
     """Uninstalls a package.
 
@@ -232,7 +241,7 @@ def uninstall(pkg):
 def get_installed_packages(path=None):
     """Return a list of installed Packages
 
-    Looks for packages in <home>/.argos-translate/packages by
+    Looks for packages in <home>/.argos-translate/local/share/packages by
     default. Will also look in the directory specified
     in the ARGOS_TRANSLATE_PACKAGE_DIR environment variable
     if it is set.
@@ -316,4 +325,7 @@ def argospm_package_name(pkg):
 
 def load_available_packages():
     """Deprecated 1.2, use get_available_packages"""
+    info(
+        "Using deprecated function load_available_packages, use get_available_packages instead"
+    )
     return get_available_packages()
